@@ -35,7 +35,7 @@
 
 #include <KLocalizedString>
 
-#define COLOURCODES "\u001B\[[0-9]*m"
+#define COLOURCODES "\u001B[[0-9]*m"
 
 using namespace Phabricator;
 
@@ -207,6 +207,7 @@ DiffRevList::DiffRevList(const QString& projectDir, QObject* parent)
 
 bool Phabricator::DiffRevList::buildArcCommand(const QString& workDir, const QString& unused, bool)
 {
+    Q_UNUSED(unused)
     bool ret;
     QString arc = QStandardPaths::findExecutable(QStringLiteral("arc"));
     if (!arc.isEmpty()) {
@@ -233,7 +234,7 @@ void DiffRevList::done(int exitCode, QProcess::ExitStatus exitStatus)
 {
     if (exitStatus != QProcess::NormalExit || exitCode) {
         setError(KJob::UserDefinedError + exitCode);
-        setErrorText(i18n("Could not get list of differential revisions in %1").arg(QDir::currentPath()));
+        setErrorText(i18n("Could not get list of differential revisions in %1", QDir::currentPath()));
         setErrorString(QString::fromUtf8(m_arcCmd.readAllStandardError()));
         qCWarning(PLUGIN_PHABRICATOR) << "Could not get list of differential revisions"
             << m_arcCmd.error() << ";" << errorString();
@@ -250,10 +251,14 @@ void DiffRevList::done(int exitCode, QProcess::ExitStatus exitStatus)
                 if (rev.startsWith(QStringLiteral("* Accepted "))) {
                     // append a Unicode "Heavy Check Mark" to signal accepted revisions
                     revTitle += QStringLiteral(" ") + QString(QChar(0x2714));
+                    m_statusMap[revTitle] = Accepted;
                 } else if (rev.startsWith(QStringLiteral("* Needs Revision "))) {
                     // append a Unicode "Heavy Ballot X" for lack of a Unicode glyph
                     // resembling the icon used on the Phab site.
                     revTitle += QStringLiteral(" ") + QString(QChar(0x2718));
+                    m_statusMap[revTitle] = NeedsRevision;
+                } else if (rev.startsWith(QStringLiteral("* Needs Review "))) {
+                    m_statusMap[revTitle] = NeedsReview;
                 }
                 m_reviews << qMakePair(revID, revTitle);
                 m_revMap[revTitle] = revID;
